@@ -29,6 +29,30 @@ sub distribution {
     return $self->{distribution};
 }
 
+sub meta_merge {
+    return {
+	'meta-spec'	=> {
+	    version	=> 2,
+	},
+	dynamic_config	=> 1,
+	no_index	=> {
+	    directory	=> [ qw{ inc t xt } ],
+	},
+	resources	=> {
+	    bugtracker	=> {
+                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Sudoku-General',
+                mailto  => 'wyant@cpan.org',
+            },
+	    license	=> 'http://dev.perl.org/licenses/',
+	    repository	=> {
+		type	=> 'git',
+		url	=> 'git://github.com/trwyant/perl-Games-Sudoku-General.git',
+		web	=> 'https://github.com/trwyant/perl-Games-Sudoku-General',
+	    },
+	}
+    };
+}
+
 sub requires {
     my ( $self, @extra ) = @_;
 
@@ -101,6 +125,16 @@ C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config>, C<no_index> and
+C<resources> data.
+
 =head2 requires
 
  use YAML;
@@ -144,7 +178,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2015 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
